import { interfaces } from "inversify";
import { API } from "lambda-api";
import { EndpointInfo } from "../model/reflection/EndpointInfo";
import { Controller } from "./Controller";
import { ErrorInterceptor } from "./error/ErrorInterceptor";
import { MiddlewareRegistry } from "./MiddlewareRegistry";
export declare type ControllerFactory = (constructor: Function) => Controller;
export declare type ErrorInterceptorFactory = (type: interfaces.ServiceIdentifier<ErrorInterceptor>) => ErrorInterceptor;
export declare class Endpoint {
    private readonly endpointInfo;
    private readonly controllerFactory;
    private readonly errorInteceptorFactory;
    private readonly middlewareRegistry;
    constructor(endpointInfo: EndpointInfo, controllerFactory: ControllerFactory, errorInteceptorFactory: ErrorInterceptorFactory, middlewareRegistry: MiddlewareRegistry);
    register(api: API): void;
    private invoke;
    private authenticateAndAuthorizeRequest;
    private authenticateRequest;
    private sendStatusCodeResponse;
    private authorizeRequest;
    private responseSent;
    private buildControllerInstance;
    /**
     * If an endpoint is function only (has no controller bound to it), we
     * build a dynamic controller which simulates a controller instance.
     */
    private buildDynamicControllerInstance;
    private setResponseContentType;
    private mapHttpMethodToCall;
    private invokeControllerMethod;
    private buildEndpointParameters;
    private getMatchingErrorInterceptor;
}
