"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that details the HTTP request Content-Type header value.
 *
 * Overrides the controller value set by the `controllerConsumes` decorator, if any.
 *
 * @param contentType Request content type.
 */
function consumes(contentType, apiBodyInfo) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        let operationInfo = endpoint.getOrCreateApiOperationInfo();
        let requestInfo = operationInfo.getOrCreateRequest();
        endpoint.consumes = contentType;
        requestInfo.contentType = contentType;
        if (apiBodyInfo) {
            requestInfo.mergeInfo(apiBodyInfo);
        }
    };
}
exports.consumes = consumes;
/**
 * Decorator for a controller class that details the HTTP request Content-Type header value for
 * all endpoints.
 *
 * @param contentType Request content type.
 */
function controllerConsumes(contentType, apiBodyInfo) {
    return (classDefinition) => {
        let apiController = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        let requestInfo = apiController.getOrCreateRequestInfo();
        apiController.consumes = contentType;
        requestInfo.contentType = contentType;
        if (apiBodyInfo) {
            requestInfo.mergeInfo(apiBodyInfo);
        }
    };
}
exports.controllerConsumes = controllerConsumes;
//# sourceMappingURL=consumes.js.map