"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const PathParameterExtractor_1 = require("../../../parameters/PathParameterExtractor");
const DecoratorRegistry_1 = require("../../../reflection/DecoratorRegistry");
/**
 * Decorator which injects a path parameter value as an endpoint parameter value.
 *
 * Value passed to the method will be a string.
 *
 * @param paramName The name of the path parameter to inject.
 */
function pathParam(paramName) {
    return (classDefinition, methodName, paramIndex) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        endpoint.parameterExtractors[paramIndex] = new PathParameterExtractor_1.PathParameterExtractor(paramName);
    };
}
exports.pathParam = pathParam;
//# sourceMappingURL=pathParam.js.map