"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that configures the type to use to intercept errors.
 *
 * Overrides the controller error interceptor set by the `controllerErrorInterceptor` decorator, if any.
 *
 * Error interceptors instances are built using the InversifyJS IOC container for the current app.
 */
function errorInterceptor(interceptor) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        endpoint.errorInterceptor = interceptor;
    };
}
exports.errorInterceptor = errorInterceptor;
/**
 * Decorator for a controller class that configures the type to use to intercept errors.
 *
 * Error interceptors instances are built using the current app InversifyJS IOC container.
 */
function controllerErrorInterceptor(interceptor) {
    return (classDefinition) => {
        let apiController = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        apiController.errorInterceptor = interceptor;
    };
}
exports.controllerErrorInterceptor = controllerErrorInterceptor;
//# sourceMappingURL=errorInterceptor.js.map