"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator that can be placed on an endpoint to describe a possible response
 * in any generated OpenAPI specification.
 *
 * @param statusCode HTTP status code that will be sent in this response.
 * @param apiBodyInfo Information about the response body generated.
 */
function apiResponse(statusCode, apiBodyInfo) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        let responses = {};
        responses[`${statusCode}`] = apiBodyInfo;
        endpoint.getOrCreateApiOperationInfo().mergeResponses(responses);
    };
}
exports.apiResponse = apiResponse;
//# sourceMappingURL=apiResponse.js.map