"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that defines roles that are allowed to use it.
 *
 * Overrides the controller roles set by the `controllerRolesAllowed` decorator, if any.
 *
 * Role based authorization is managed by an `IAuthorizer` implementation registered
 * with the current app.
 *
 * @param roleNames Names of roles that are permitted to use the endpoint.
 */
function rolesAllowed(...roleNames) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        endpoint.rolesAllowed = roleNames;
    };
}
exports.rolesAllowed = rolesAllowed;
/**
 * Decorator for a controller class that defines roles that are allowed to user all
 * endpoints within it.
 *
 * Role based authorization is managed by a `IAuthorizer` implementation registered
 * with the current app.
 *
 * @param roleNames Names of roles that are permitted to use the endpoints in this controller.
 */
function controllerRolesAllowed(...roleNames) {
    return (classDefinition) => {
        let apiController = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        apiController.rolesAllowed = roleNames;
    };
}
exports.controllerRolesAllowed = controllerRolesAllowed;
//# sourceMappingURL=rolesAllowed.js.map