"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AuthFilterInfo_1 = require("../../model/open-api/AuthFilterInfo");
const ControllerInfo_1 = require("../../model/reflection/ControllerInfo");
const EndpointInfo_1 = require("../../model/reflection/EndpointInfo");
class DecoratorRegistry {
    static getOrCreateController(constructor) {
        let name = constructor.name;
        if (!DecoratorRegistry.Controllers[name]) {
            DecoratorRegistry.Controllers[name] = new ControllerInfo_1.ControllerInfo(name, constructor);
        }
        return DecoratorRegistry.Controllers[name];
    }
    static getOrCreateEndpoint(controller, methodName) {
        let endpointKey = `${controller.name}::${methodName}`;
        if (!DecoratorRegistry.Endpoints[endpointKey]) {
            DecoratorRegistry.Endpoints[endpointKey] = new EndpointInfo_1.EndpointInfo(endpointKey, controller, methodName);
        }
        controller.endpoints[methodName] = DecoratorRegistry.Endpoints[endpointKey];
        return DecoratorRegistry.Endpoints[endpointKey];
    }
    static getOrCreateAuthFilter(constructor) {
        let name = constructor.name;
        if (!DecoratorRegistry.AuthFilters[name]) {
            DecoratorRegistry.AuthFilters[name] = new AuthFilterInfo_1.AuthFilterInfo();
        }
        return DecoratorRegistry.AuthFilters[name];
    }
}
// these are required to be dictionaries, using Map here causes weird issues with persistance
DecoratorRegistry.Endpoints = {};
DecoratorRegistry.Controllers = {};
DecoratorRegistry.AuthFilters = {};
exports.DecoratorRegistry = DecoratorRegistry;
//# sourceMappingURL=DecoratorRegistry.js.map